'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = createMeta;
function createMeta(type) {
  var sameActionType = true;
  var actionTypes = { request: 'request', success: 'success', failure: 'failure' };

  if (typeof type === 'string') {
    if (!type.length) {
      throw new Error('Missing action type given to createMeta.');
    }
  } else {
    var request = type.request;
    var success = type.success;
    var failure = type.failure;

    if (!request || !success || !failure) {
      throw new Error('Missing or invalid action type(s) given to createMeta.');
    }
    sameActionType = false;
    actionTypes = { request: request, success: success, failure: failure };
  }

  var initialState = { isFetching: false, lastUpdated: undefined, error: false };

  return function () {
    var state = arguments.length <= 0 || arguments[0] === undefined ? initialState : arguments[0];
    var action = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];
    var _action$error = action.error;
    var error = _action$error === undefined ? true : _action$error;


    if (sameActionType && action.type !== type) {
      return state;
    }

    switch (sameActionType ? action.status : action.type) {
      case actionTypes.request:
        return Object.assign({}, state, { isFetching: true });
      case actionTypes.success:
        return { isFetching: false, lastUpdated: action.now, error: false };
      case actionTypes.failure:
        return { isFetching: false, lastUpdated: action.now, error: error };
      default:
        return state;
    }
  };
}